summaryrefslogtreecommitdiff
path: root/libguile/eval.c
diff options
context:
space:
mode:
authorMikael Djurfeldt <djurfeldt@nada.kth.se>1996-10-05 16:49:31 +0000
committerMikael Djurfeldt <djurfeldt@nada.kth.se>1996-10-05 16:49:31 +0000
commit1646d37b71a88e2f953a0bf7b22a5451009f9f00 (patch)
treef48d008229530be9220cc62a951f7b62f59c12a7 /libguile/eval.c
parent02ba201059803306cf598ba4d08faa549b3578e3 (diff)
downloadguile-1646d37b71a88e2f953a0bf7b22a5451009f9f00.tar.gz
* continuations.c, debug.[ch], eval.c, gscm.c init.c, root.c,
throw.c: Renamed last_debug_info_frame -> scm_last_debug_frame.
Diffstat (limited to 'libguile/eval.c')
-rw-r--r--libguile/eval.c18
1 files changed, 10 insertions, 8 deletions
diff --git a/libguile/eval.c b/libguile/eval.c
index 93d19af2f..1570a4592 100644
--- a/libguile/eval.c
+++ b/libguile/eval.c
@@ -1324,14 +1324,16 @@ SCM (*scm_ceval_ptr) (SCM exp, SCM env);
SCM (*scm_ceval_ptr) ();
#endif
/* last_debug_info_frame contains a pointer to the last debugging
* information stack frame. It is accessed very often from the
* debugging evaluator, so it should probably not be indirectly
* addressed. Better to save and restore it from the current root at
* any stack swaps.
*/
-scm_debug_frame *last_debug_info_frame;
+#ifndef USE_THREADS
+scm_debug_frame *scm_last_debug_frame;
+#endif
/* scm_debug_eframe_size is the number of slots available for pseudo
* stack frames at each real stack frame.
@@ -1447,10 +1449,10 @@ SCM_CEVAL (x, env)
scm_debug_info vect[scm_debug_eframe_size];
scm_debug_info *info;
} debug;
- debug.prev = last_debug_info_frame;
+ debug.prev = scm_last_debug_frame;
debug.status = scm_debug_eframe_size;
debug.info = &debug.vect[0];
- last_debug_info_frame = (scm_debug_frame *) &debug;
+ scm_last_debug_frame = (scm_debug_frame *) &debug;
#endif
#ifdef EVAL_STACK_CHECKING
if (SCM_STACK_OVERFLOW_P ((SCM_STACKITEM *) &proc)
@@ -2305,7 +2307,7 @@ exit:
scm_ithrow (scm_i_exit_frame, scm_cons2 (t.arg1, proc, SCM_EOL), 0);
}
ret:
- last_debug_info_frame = debug.prev;
+ scm_last_debug_frame = debug.prev;
return proc;
#endif
}
@@ -2427,11 +2429,11 @@ SCM_APPLY (proc, arg1, args)
#ifdef DEBUG_EXTENSIONS
#ifdef DEVAL
scm_debug_frame debug;
- debug.prev = last_debug_info_frame;
+ debug.prev = scm_last_debug_frame;
debug.status = SCM_APPLYFRAME;
debug.vect[0].a.proc = proc;
debug.vect[0].a.args = SCM_EOL;
- last_debug_info_frame = &debug;
+ scm_last_debug_frame = &debug;
#else
if (SCM_DEBUGGINGP)
return scm_dapply (proc, arg1, args);
@@ -2622,7 +2624,7 @@ exit:
scm_ithrow (scm_i_exit_frame, scm_cons2 (arg1, proc, SCM_EOL), 0);
}
ret:
- last_debug_info_frame = debug.prev;
+ scm_last_debug_frame = debug.prev;
return proc;
#endif
}
@@ -1324,14 +1324,16 @@ SCM (*scm_ceval_ptr) (SCM exp, SCM env);
SCM (*scm_ceval_ptr) ();
#endif
-/* last_debug_info_frame contains a pointer to the last debugging
+/* scm_last_debug_frame contains a pointer to the last debugging
* information stack frame. It is accessed very often from the
* debugging evaluator, so it should probably not be indirectly